==> nextcloud-31.0.7.tgz: nextcloud/apps/photos/l10n/sw.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Kiungio cha umma",
    "Photos" : "Picha",
    "On This Day" : "Katika siku hii",
    "Your memories under your control" : "Kumbukumbu zako chini ya udhibiti wako",
    "All media" : "Media zote",
    "Videos" : "Picha mjongeo",
    "Albums" : "Albamu",
    "Collaborative albums" : "Collaborative albums",
    "People" : "Watu",
    "Folders" : "Visanduku",
    "Favorites" : "Vipendwa",
    "On this day" : "Katika siku hii",
    "Shared with you" : "Imeshirikiwa na wewe",
    "Tags" : "Maoni",
    "Places" : "Maeneo",
    "Map" : "Ramani",
    "Photos settings" : "Mipangilio ya picha",
    "Mark selection as favorite" : "Wekea alama uteuzi kutoka kwa vipendwa",
    "Add selection to favorites" : "Ongeza uteuzi kutoka kwa vipendwa",
    "Remove selection from favorites" : "Ondoa uteuzi kutoka kwa vipendwa",
    "Name of the album" : "Jina la albamu",
    "Location of the album" : "Eneo la albamu",
    "Back" : "Rudi",
    "Add collaborators" : "Add collaborators",
    "Save" : "Hifadhi",
    "Create album" : "Tengeneza albamu",
    "Add to Album" : "Ongeza katika albamu",
    "Add selection to album {albumName}" : "Ongeza mchaguo kwenye albamu {albumName}",
    "Shared by" : "Imeshirikishwa na",
    "Create a new album." : "Tengeneza albamu mpya",
    "Create new album" : "Tengeneza albamu mpya",
    "New album" : "Albamu mpya",
    "_%n item_::_%n photos and videos_" : ["%n item","%n picha na video"],
    "Failed to fetch collaborators list." : "Imeshindwa kuleta orodha ya washiriki",
    "Failed to update album." : "Imeshindwa kusasisha albamu",
    "Add people or groups who can edit your album" : "Ongeza watu au makundi ambao wanaweza kuhariri albamu yako",
    "Search people or groups" : "Tafuta watu au makundi",
    "No recommendations. Start typing." : "Hakuna maoni. Anza kuchapisha",
    "Group" : "Kundi",
    "Remove {collaboratorLabel} from the collaborators list" : "Ondoa {collaboratorLabel}kutoka kwenye orodha ya washiriki",
    "Copy the public link" : "Nakili kiungio cha umma",
    "Public link copied!" : "Kiungio cha umma kimenakiliwa",
    "Copy public link" : "Nakili kiungo cha umma",
    "Delete the public link" : "Futa kiungio cha umma",
    "Create public link share" : "Tengeneza ushirikishaji kwa kiungio cha umma",
    "Share via public link" : "Shirikisha kupitia kiungio cha umma",
    "This collection does not exist" : "Mkusanyiko huu haupo",
    "An error occurred" : "Hitilafu imetokea",
    "No picture for this day" : "Hakuna picha kwa siku hii",
    "Picture taken on this day will show up here." : "Picha iliyochukuliwa siku hii itaonekana hapa",
    "More photos from this day" : "Picha zaidi kutoka siku hii",
    "_%n photos_::_%n photos_" : ["%n photos","%n picha"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n unassigned photo","%n picha ambayo haijakabidhiwa"],
    "Favorite" : "Kipendwa",
    "Favorite image, open the full size \"{name}\" image" : "Taswira pendwa, fungua ukubwa kamili \"{name}\" taswira",
    "Open the full size \"{name}\" image" : "Fungua ukubwa kamili \"{{name}}\" taswira",
    "Select image {imageName}" : "Chagua taswaira {imageName}",
    "Open the \"{name}\" folder" : "Fungua \"{name}\" kisanduku",
    "Go back" : "Rudi nyuma",
    "Date range" : "Safu za tarehe",
    "Select a date range" : "Chagua safu za tarehe",
    "Select places" : "Chagua maeneo",
    "Dates" : "Tarehe",
    "Jump to specific date in list" : "Rukia tarehe halisi katika orodha",
    "Jump to {date}" : "Rukia kwenye {date}",
    "Add to {destination}" : "Ongeza kwenye {destination}",
    "The destination folder is owned by {owner}" : "Kisanduku lengwa kinamilikwa na {owner}",
    "There are no photos or videos yet!" : "Bado hakuna picha au video",
    "_{years} year ago_::_{years} years ago_" : ["{years} year ago","{years} miaka iliyopita"],
    "Enable squared photos view" : "Washa mwonekano wa picha za mraba",
    "Delete source directory" : "Futa saraka ya chanzo",
    "Pick folder" : "Chagua kisanduku",
    "Select a source folder for your media" : "Chagua kisanduku chanzo kwa midia yako",
    "All folders" : "Vikasha vyote",
    "Add a Photos source for the timelines" : "Ongeza chanzo cha Picha kwa kalenda ya matukio",
    "Add folder" : "Ongeza kisanduku",
    "Select the default upload location for your media" : "Chagua eneo chaguomsingi la kupakia kwa midia yako",
    "Home" : "Nyumbani",
    "Choose default Photos upload and Albums location" : "Chagua upakiaji chaguomsingi wa Picha na eneo la Albamu",
    "Choose a different folder" : "Chagua kisanduku tofauti",
    "View" : "Angalia",
    "Media folders" : "Kisanduku cha midia",
    "Choose the folders from where photos and videos are shown." : "Chagua kisanduku ambapo picha na video zinaonyeshwa.",
    "Upload folder" : "Pakia kisanduku",
    "Choose the folder where photos and albums are uploaded to." : "Chagua folda ambapo picha na albamu hupakiwa",
    "_%n photo_::_%n photos_" : ["%n photo","%n picha"],
    "Unselect all" : "Acha kuchagua zote",
    "Toggle filter" : "Geuza kichujio",
    "Add photos to this album" : "Ongeza picha kwa albamu hii",
    "Manage collaborators for this album" : "Dhibiti washirika wa albamu hii",
    "Open actions menu" : "Fungua mwongozo wa vitendo",
    "Edit album details" : "Hariri maelezo ya albamu",
    "Download all files in album" : "Pakua faili zote katika albamu",
    "Delete album" : "Futa albamu",
    "Download selected files" : "Pakua faili zilizochzguliwa",
    "Remove selection from album" : "Futa machaguo kutoka kwenye albamu",
    "This album does not have any photos or videos yet!" : "Bado albamu hii haina picha yoyote na video",
    "Add photos to {albumName}" : "Ongeza picha kwenye {albumName}",
    "Manage collaborators" : "Simamia washiriki",
    "Save collaborators for this album." : "Hifadhi washiriki kwa albamu hii ",
    "Cover photo for album {albumName}" : "Picha ya jalada kwa albamu {albumName}",
    "There is no album yet!" : "Bado hakuna albamu",
    "This person could not be found" : "Mtu huyu hawezi kupatikana",
    "Rename person" : "Badilisha jina la mtu",
    "Merge with different person" : "Ungana na mtu tofauti",
    "Download selected photos" : "Pakua picha zilizoteuliwa",
    "Remove from favorites" : "Ondoa kutoka katika pendwa",
    "Remove person" : "Ondoa mtu",
    "Name of this person" : "Jina la mtu huyu",
    "Save." : "Hifadhi",
    "Merge person" : "Unganisha mtu ",
    "Move to different person" : "Hamisha kwa mtu tofauti",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Move photo to a different person","Hamisha picha kwa mtu tofauti"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remove photo from person","Hamisha picha kutoka kwa mtu"],
    "This might take some time depending on the size of your photo library." : "Hii inaweza kuchukua muda kulingana na ukubwa wa maktaba yako ya picha.",
    "Recognized people will show up here" : "Watu wanaotambulika watajitokeza hapa\n ",
    "This folder does not exist" : "Kisanduku hiki hakipo",
    "Loading folders …" : "Inapakia visanduku",
    "No photos in here" : "Hakuna picha hapa",
    "Taken on {date} at {time}" : "Imechukuliwa juu ya {date} katika {time}",
    "This place does not have any photos or videos yet!" : "Eneo hili bado halina picha wala video zozote!",
    "Add photos to this place" : "Ongeza picha katika eneo hili",
    "Cover photo for place {placeName}" : "Picha ya jalada kwa eneo {placeName}",
    "There is no place yet!" : "Bado hakuna eneo",
    "Cover photo for shared album {albumName}" : "Jalada ia picha kwa albamu zilizoshirikishwa {albumName}",
    "Back to tags overview" : "Rudi kwa muhtasari wa lebo",
    "No photos with this tag yet" : "Bado hakuna picha zilizo na lebo hii",
    "No tags yet" : "Bado hakuna lebo",
    "Photos with tags will show up here" : "Picha zilizo na lebo zitaonekana hapa",
    "Popular tags" : "Lebo maarufu",
    "All tags" : "Lebo zote",
    "Create new album from filters" : "Unda albamu mpya kutoka kwa vichujio",
    "One of the source folders does not exist" : "Moja ya visanduku chanzo havipo",
    "Add to album" : "Ongeza kwenye albamu",
    "Delete selection" : "Futa machaguo",
    "No photos or videos in here" : "Hakuna picha au video hapa",
    "Unassigned faces" : "Nyuso ambazo hazijakabidhiwa",
    "Failed to fetch collection." : "Imeshindwa kuleta makusanyo",
    "Failed to fetch collections list." : "Imeshindwa kuleta orodha ya makusanyo",
    "Failed to fetch faces list." : "Imeshindwa kuleta orodha ya nyuso",
    "Error fetching files" : "Hitilafu wakati wa kuleta faili",
    "All your media" : "Midia zako zote",
    "Album {title}" : "Albamu {title}",
    "Shared Albums" : "Albamu zilizoshirikishwa ",
    "Shared album {title}" : "Albamu iliyoshirikishwa {title}",
    "Public album {title}" : "Albamu ya umma {title}",
    "Tagged photos" : "Picha zilizowekwa alama",
    "Tagged photo {title}" : "Picha iliyowekwa alama {title}",
    "{title}'s face" : "{title}uso",
    "{startDate} to {endDate}" : "{startDate} kwenda {endDate}",
    "Details" : "Maelezo ya kina",
    "Failed to delete {fileBaseName}" : "Imeshindwa kufuta {fileBaseName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Imeshindwa kuita jina upya {currentCollectionFileName} kwenda {newCollectionFileName}",
    "Failed to delete {collectionFileName}" : "Imeshindwa kufuta {collectionFileName}",
    "Failed to rename {oldName} to {faceName}" : "Imeshindwa kuita jina upya {oldName} kwenda {faceName}",
    "Failed to delete {faceName}" : "Imeshindwa kufuta {faceName}",
    "Failed to delete {fileId}" : "Imeshindwa kufuta {fileId}",
    "Failed to delete {fileName}" : "Imeshindwa kufuta {fileName}",
    "Failed to set favorite state for {fileId}" : "Imeshindwa kuweka hali pendwa ya {fileId}",
    "Failed to set favorite state for {fileName}" : "Imeshindwa kuweka hali pendwa ya  {fileName}",
    "Could not load photos folder" : "Isingeweza kupakia kisanduku cha picha",
    "Back to {folder}" : "Rudi kwenye {folder}",
    "Share this folder" : "Shirikisha kisanduku hiki",
    "One of the source folders does not exists" : "Moja ya folda chanzo haipo",
    "Add" : "Ongeza"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/photos/l10n/sw.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Kiungio cha umma",
    "Photos" : "Picha",
    "On This Day" : "Katika siku hii",
    "Your memories under your control" : "Kumbukumbu zako chini ya udhibiti wako",
    "All media" : "Media zote",
    "Videos" : "Picha mjongeo",
    "Albums" : "Albamu",
    "Collaborative albums" : "Collaborative albums",
    "People" : "Watu",
    "Folders" : "Visanduku",
    "Favorites" : "Vipendwa",
    "On this day" : "Katika siku hii",
    "Shared with you" : "Imeshirikiwa na wewe",
    "Tags" : "Maoni",
    "Places" : "Maeneo",
    "Map" : "Ramani",
    "Photos settings" : "Mipangilio ya picha",
    "Mark selection as favorite" : "Wekea alama uteuzi kutoka kwa vipendwa",
    "Add selection to favorites" : "Ongeza uteuzi kutoka kwa vipendwa",
    "Remove selection from favorites" : "Ondoa uteuzi kutoka kwa vipendwa",
    "This name is already in use." : "Jina hili liko katika matumizi tayari",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" hairuhusiwi ndani ya jina la faili",
    "Invalid filename." : "Majina ya faili si sahihi",
    "Name of the album" : "Jina la albamu",
    "Location of the album" : "Eneo la albamu",
    "Back" : "Rudi",
    "Add collaborators" : "Add collaborators",
    "Save" : "Hifadhi",
    "Create album" : "Tengeneza albamu",
    "Add to Album" : "Ongeza katika albamu",
    "Add selection to album {albumName}" : "Ongeza mchaguo kwenye albamu {albumName}",
    "Shared by" : "Imeshirikishwa na",
    "Create a new album." : "Tengeneza albamu mpya",
    "Create new album" : "Tengeneza albamu mpya",
    "New album" : "Albamu mpya",
    "_%n item_::_%n photos and videos_" : ["%n item","%n picha na video"],
    "Failed to fetch collaborators list." : "Imeshindwa kuleta orodha ya washiriki",
    "Failed to update album." : "Imeshindwa kusasisha albamu",
    "Add people or groups who can edit your album" : "Ongeza watu au makundi ambao wanaweza kuhariri albamu yako",
    "Search people or groups" : "Tafuta watu au makundi",
    "No recommendations. Start typing." : "Hakuna maoni. Anza kuchapisha",
    "Copy the public link" : "Nakili kiungio cha umma",
    "Public link copied!" : "Kiungio cha umma kimenakiliwa",
    "Copy public link" : "Nakili kiungo cha umma",
    "Delete the public link" : "Futa kiungio cha umma",
    "Create public link share" : "Tengeneza ushirikishaji kwa kiungio cha umma",
    "Share via public link" : "Shirikisha kupitia kiungio cha umma",
    "This collection does not exist" : "Mkusanyiko huu haupo",
    "An error occurred" : "Hitilafu imetokea",
    "No picture for this day" : "Hakuna picha kwa siku hii",
    "Picture taken on this day will show up here." : "Picha iliyochukuliwa siku hii itaonekana hapa",
    "More photos from this day" : "Picha zaidi kutoka siku hii",
    "_%n photos_::_%n photos_" : ["%n photos","%n picha"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n unassigned photo","%n picha ambayo haijakabidhiwa"],
    "Favorite" : "Kipendwa",
    "Favorite image, open the full size \"{name}\" image" : "Taswira pendwa, fungua ukubwa kamili \"{name}\" taswira",
    "Open the full size \"{name}\" image" : "Fungua ukubwa kamili \"{name}\" taswira",
    "Select image {imageName}" : "Chagua taswaira {imageName}",
    "Open the \"{name}\" folder" : "Fungua \"{name}\" kisanduku",
    "Go back" : "Rudi nyuma",
    "Select a custom date range" : "Chagua kipindi maalum cha tarehe",
    "Select a date range" : "Chagua safu za tarehe",
    "Date range" : "Safu za tarehe",
    "Select filters" : "Chagua vichujio",
    "Dates" : "Tarehe",
    "Jump to specific date in list" : "Rukia tarehe halisi katika orodha",
    "Jump to {date}" : "Rukia kwenye {date}",
    "Add to {destination}" : "Ongeza kwenye {destination}",
    "The destination folder is owned by {owner}" : "Kisanduku lengwa kinamilikwa na {owner}",
    "There are no photos or videos yet!" : "Bado hakuna picha au video",
    "_{years} year ago_::_{years} years ago_" : ["{years} year ago","{years} miaka iliyopita"],
    "Enable squared photos view" : "Washa mwonekano wa picha za mraba",
    "Delete source directory" : "Futa saraka ya chanzo",
    "Pick folder" : "Chagua kisanduku",
    "Select a source folder for your media" : "Chagua kisanduku chanzo kwa midia yako",
    "All folders" : "Vikasha vyote",
    "Add a Photos source for the timelines" : "Ongeza chanzo cha Picha kwa kalenda ya matukio",
    "Add folder" : "Ongeza kisanduku",
    "Select the default upload location for your media" : "Chagua eneo chaguomsingi la kupakia kwa midia yako",
    "Home" : "Nyumbani",
    "Choose default Photos upload and Albums location" : "Chagua upakiaji chaguomsingi wa Picha na eneo la Albamu",
    "Choose a different folder" : "Chagua kisanduku tofauti",
    "View" : "Angalia",
    "Media folders" : "Kisanduku cha midia",
    "Choose the folders from where photos and videos are shown." : "Chagua kisanduku ambapo picha na video zinaonyeshwa.",
    "Upload folder" : "Pakia kisanduku",
    "Choose the folder where photos and albums are uploaded to." : "Chagua folda ambapo picha na albamu hupakiwa",
    "_%n photo_::_%n photos_" : ["%n photo","%n picha"],
    "Unselect all" : "Acha kuchagua zote",
    "Add photos to this album" : "Ongeza picha kwa albamu hii",
    "Manage collaborators for this album" : "Dhibiti washirika wa albamu hii",
    "Open actions menu" : "Fungua mwongozo wa vitendo",
    "Edit album details" : "Hariri maelezo ya albamu",
    "Download all files in album" : "Pakua faili zote katika albamu",
    "Delete album" : "Futa albamu",
    "Download selected files" : "Pakua faili zilizochzguliwa",
    "Remove selection from album" : "Futa machaguo kutoka kwenye albamu",
    "This album does not have any photos or videos yet!" : "Bado albamu hii haina picha yoyote na video",
    "Add photos to {albumName}" : "Ongeza picha kwenye {albumName}",
    "Manage collaborators" : "Simamia washiriki",
    "Save collaborators for this album." : "Hifadhi washiriki kwa albamu hii ",
    "Cover photo for album {albumName}" : "Picha ya jalada kwa albamu {albumName}",
    "There is no album yet!" : "Bado hakuna albamu",
    "This person could not be found" : "Mtu huyu hawezi kupatikana",
    "Rename person" : "Badilisha jina la mtu",
    "Merge with different person" : "Ungana na mtu tofauti",
    "Download selected photos" : "Pakua picha zilizoteuliwa",
    "Remove from favorites" : "Ondoa kutoka katika pendwa",
    "Remove person" : "Ondoa mtu",
    "Name of this person" : "Jina la mtu huyu",
    "Save." : "Hifadhi",
    "Merge person" : "Unganisha mtu ",
    "Move to different person" : "Hamisha kwa mtu tofauti",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Move photo to a different person","Hamisha picha kwa mtu tofauti"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remove photo from person","Hamisha picha kutoka kwa mtu"],
    "This might take some time depending on the size of your photo library." : "Hii inaweza kuchukua muda kulingana na ukubwa wa maktaba yako ya picha.",
    "Recognized people will show up here" : "Watu wanaotambulika watajitokeza hapa",
    "This folder does not exist" : "Kisanduku hiki hakipo",
    "Loading folders…" : "Inapakia folda...",
    "No photos in here" : "Hakuna picha hapa",
    "Taken on {date} at {time}" : "Imechukuliwa juu ya {date} katika {time}",
    "This place does not have any photos or videos yet!" : "Eneo hili bado halina picha wala video zozote!",
    "Add photos to this place" : "Ongeza picha katika eneo hili",
    "Cover photo for place {placeName}" : "Picha ya jalada kwa eneo {placeName}",
    "There is no place yet!" : "Bado hakuna eneo",
    "Cover photo for shared album {albumName}" : "Jalada ia picha kwa albamu zilizoshirikishwa {albumName}",
    "Back to tags overview" : "Rudi kwa muhtasari wa lebo",
    "No photos with this tag yet" : "Bado hakuna picha zilizo na lebo hii",
    "No tags yet" : "Bado hakuna lebo",
    "Photos with tags will show up here" : "Picha zilizo na lebo zitaonekana hapa",
    "Popular tags" : "Lebo maarufu",
    "All tags" : "Lebo zote",
    "Create new album from filters" : "Unda albamu mpya kutoka kwa vichujio",
    "One of the source folders does not exist" : "Moja ya visanduku chanzo havipo",
    "Add to album" : "Ongeza kwenye albamu",
    "Delete selection" : "Futa machaguo",
    "No photos or videos in here" : "Hakuna picha au video hapa",
    "Unassigned faces" : "Nyuso ambazo hazijakabidhiwa",
    "Failed to fetch collection." : "Imeshindwa kuleta makusanyo",
    "Failed to fetch collections list." : "Imeshindwa kuleta orodha ya makusanyo",
    "Failed to fetch faces list." : "Imeshindwa kuleta orodha ya nyuso",
    "Error fetching files" : "Hitilafu wakati wa kuleta faili",
    "All your media" : "Midia zako zote",
    "Album {title}" : "Albamu {title}",
    "Shared Albums" : "Albamu zilizoshirikishwa ",
    "Shared album {title}" : "Albamu iliyoshirikishwa {title}",
    "Public album {title}" : "Albamu ya umma {title}",
    "Tagged photos" : "Picha zilizowekwa alama",
    "Tagged photo {title}" : "Picha iliyowekwa alama {title}",
    "{title}'s face" : "{title}uso",
    "Last week" : "Wiki iliyopita",
    "Last Month" : "Mwezi uliopita",
    "Custom…" : "Desturi...",
    "{startDate} to {endDate}" : "{startDate} kwenda {endDate}",
    "Details" : "Maelezo ya kina",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Imeshindwa kuongeza {fileBaseName} kwa mkusanyiko {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Imeshindwa kufuta {fileBaseName}",
    "Failed to create {collectionFileName}" : "Imeshindwa kutengeneza {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Imeshindwa kuita jina upya {currentCollectionFileName} kwenda {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Imeshindwa kusasisha sifa za {collectionFileName} na {properties}",
    "Failed to delete {collectionFileName}" : "Imeshindwa kufuta {collectionFileName}",
    "Failed to move {fileBaseName} to person {faceName}" : "Imeshindwa kuhamisha {fileBaseName} kwa mtu {faceName}",
    "Failed to remove {fileBaseName}" : "Imeshindwa kuhamisha {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Imeshindwa kuita jina upya {oldName} kwenda {faceName}",
    "Failed to delete {faceName}" : "Imeshindwa kufuta {faceName}",
    "Failed to delete {fileId}" : "Imeshindwa kufuta {fileId}",
    "Failed to delete {fileName}" : "Imeshindwa kufuta {fileName}",
    "Failed to set favorite state for {fileId}" : "Imeshindwa kuweka hali pendwa ya {fileId}",
    "Failed to set favorite state for {fileName}" : "Imeshindwa kuweka hali pendwa ya  {fileName}",
    "Could not load photos folder" : "Isingeweza kupakia kisanduku cha picha",
    "Group" : "Kundi",
    "Remove {collaboratorLabel} from the collaborators list" : "Ondoa {collaboratorLabel}kutoka kwenye orodha ya washiriki",
    "Back to {folder}" : "Rudi kwenye {folder}",
    "Share this folder" : "Shirikisha kisanduku hiki",
    "Loading folders …" : "Inapakia visanduku",
    "Add" : "Ongeza"
},
"nplurals=2; plural=(n != 1);");
